<?php
/**
 * Endpoints: subscribers_list
 * @see https://freshmail.com/developer-api/subscribers-subscriber-management/
 *
 * @author MS
 */
namespace Freshmail\Core\Api\Endpoints;

class SubscribersList extends AbstractEndpoint
{
  /**
   * Creates subscribers list
   *
   * @return array
   * @author MS
   */
  public function create(string $name, string $description = '', array $custom_fields = []): array
  {
    $data = [
      'name' => $name,
      'description' => $description,
      'custom_fields' => $custom_fields,
    ];
    $json_payload = json_encode($data);
    $rseult = $this->call('rest/subscribers_list/create', $json_payload, 'POST');
    return $rseult;
  }

  /**
   * Adds custom field to list
   *
   * @return array
   * @author MS
   */
  public function addField(string $hash, string $name, string $tag = '', int $type = 0): array
  {
    if (empty($hash)) {
      $hash = $this->api_config->getCurrentList();
    }

    $data = [
      'hash' => $hash,
      'name' => $name,
      'tag' => $tag,
      'type' => $type,
    ];
    $json_payload = json_encode($data);
    $rseult = $this->call('rest/subscribers_list/addField', $json_payload, 'POST');
    return $rseult;
  }

  /**
   * Gets custom field of list
   *
   * @return array
   * @author MS
   */
  public function getFields(string $hash): array
  {
    $data = [
      'hash' => $hash,
    ];
    $json_payload = json_encode($data);
    $rseult = $this->call('rest/subscribers_list/getFields', $json_payload, 'POST');
    return $rseult;
  }

  /**
   * Gets lists
   *
   * @return array
   * @author MS
   */
  public function lists(): array
  {
    $rseult = $this->call('rest/subscribers_list/lists', '', 'GET');
    return $rseult;
  }
}
