<?php
/**
 * Model: API Config
 *
 * @author MS
 */
namespace Freshmail\Core\Api\Models;

class ApiConfig
{
  private string $api_token;

  private string $api_base_url = 'https://api.freshmail.com/';

  private string $current_list = '';

  private int $new_subscriber_status = 2;

  public function __construct()
  {
    $this->init();

    if (empty($this->getToken())) {
      // throw new \Exception('Freshmail: API token empty.');
      error_log('Freshmail ERROR: No token set!');
    }

    if (empty($this->getCurrentList())) {
      // throw new \Exception('Freshmail: Subscribers list empty.');
      error_log('Freshmail ERROR: No current subscribers list set!');
    }
  }

  private function init(): void
  {
    $this->setToken(get_option('f_bearer_token', ''));
    $this->setCurrentList(get_option('f_subscribers_list_hash', ''));
    $this->setNewSubscriberStatus(get_option('f_new_subscriber_status', 2));
  }

  public function getToken(): string
  {
    return $this->api_token;
  }

  public function setToken(string $api_token): void
  {
    $this->api_token = $api_token;
  }

  public function getBearer(): string
  {
    return $this->getToken();
  }

  public function setBearer(string $api_token): void
  {
    $this->setToken($api_token);
  }

  public function getBaseUrl(): string
  {
    return $this->api_base_url;
  }

  public function setBaseUrl(string $api_base_url): void
  {
    $this->api_base_url = $api_base_url;
  }

  public function getCurrentList(): string
  {
    return $this->current_list;
  }

  public function setCurrentList(string $current_list): void
  {
    $this->current_list = $current_list;
  }

  public function getNewSubscriberStatus(): int
  {
    return $this->new_subscriber_status;
  }

  public function setNewSubscriberStatus(int $new_subscriber_status): void
  {
    $this->new_subscriber_status = $new_subscriber_status > 0 ? $new_subscriber_status : 2;
  }
}
