<?php

namespace Freshmail\SetupWizard\Section;

class Input
{
  private string $name;

  private string $type;

  private string $nonce;

  private ?array $options;

  private ?string $placeholder;

  private ?string $class;

  /**
   * @var mixed
   */
  private $value;

  public function __construct(string $name, array $settings)
  {
    $defaults = [
      'type' => 'text',
      'value' => '',
      'nonce' => wp_create_nonce($name),
      'class' => '--' . $name,
      'options' => [],
      'placeholder' => '',
      'html' => '',
    ];
    $data = wp_parse_args($settings, $defaults);

    $this->name = $name;
    $this->type = $data['type'];
    $this->value = $data['value'];
    $this->nonce = $data['nonce'];
    $this->class = $data['class'];
    $this->options = $data['options'];
    $this->placeholder = $data['placeholder'];
    $this->html = $this->generateHtml();
  }

  public function getName(): string
  {
    return $this->name;
  }

  public function getType(): string
  {
    return $this->type;
  }

  public function getHtml(): string
  {
    return $this->html;
  }

  private function generateHtml()
  {
    $name = $this->name; // this is used by templates
    $value = $this->value;
    $options = $this->options;
    $placeholder = $this->placeholder;
    $class = $this->class;
    $nonce = $this->nonce;
    $path = FRERSHMAIL_RESOURCES_PATH . 'views/setup-wizard/inputs/' . $this->type . '.php';
    ob_start();

    if (file_exists($path)) {
      include $path;
    } else {
      include FRERSHMAIL_RESOURCES_PATH . 'views/setup-wizard/inputs/default.php';
    }

    $html = ob_get_clean();

    return $html;
  }
}
